@@ -17,8 +17,8 @@ $path = quotemeta($path);
 
 # Quaduple quoting of backslashes is necessary!
 my $sth = $dbh->prepare(<<WQL);
-    SELECT * FROM CIM_Datafile 
-    WHERE 
+    SELECT Drive, Path, Name FROM CIM_Datafile
+    WHERE
         Drive = '$drive'
      AND Path  = '$path'
      AND Extension = 'pl'
@@ -26,7 +26,8 @@ WQL
 
 $sth->execute();
 while (defined (my $row = $sth->fetchrow_arrayref())) {
-    my $ev = $row->[0];
-    print join "\t", $ev->Drive, $ev->Path, $ev->Name;
+    #my $ev = $row->[0];
+    print join "\t", @$row;
+    #print join "\t", $ev->Drive, $ev->Path, $ev->Name;
     print "\n";
-}
+}
\ No newline at end of file
