@@ -1,10 +1,10 @@
 package DBD::WMI;
 use strict;
-use base 'DBD::File';
+use parent 'DBD::File';
 use DBI;
 
 our $ATTRIBUTION = 'DBD::WMI by Max Maischein <dbd-wmi@corion.net>';
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 NAME
 
